/***************************************************************************
 *   Copyright (C) 2002-2006, the RPPPPoEK developers                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef _RPPPPOEK_H_
#define _RPPPPOEK_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kapp.h>
#include <ksystemtray.h>
#include <kprocess.h>
#include <kdialog.h>
#include <kaction.h>

#include <qtimer.h>

const int TIMER_CHECK_INTERVAL		= 1000;	// in ms
const int TIMER_ANIMATION_INTERVAL	= 120;	// in ms
const int TIMER_ANIMATION_COUNT		= 12;	// total no. of animation icons
const QString DEVICE_LIST			= "/proc/net/dev"; // where to get up/down state and traffic from
const QString DEVICE_NAME			= "ppp0"; // which device to monitor
const QString SCRIPT				= "rppppoek.sh"; // helper script for dialup/hangup

/**
 * @short Application Main Window
 * @author the RPPPPoEK developers
 * @version 0.40
 */
class rppppoek : public KSystemTray
{
	Q_OBJECT
public:
	/**
	  * Default Constructor
	  */
	rppppoek(KDialog* dialog, QWidget* parent=0, const char *name=0);

	/**
	  * Default Destructor
	  */
	virtual ~rppppoek();

private:
	KDialog* dlgAbout;

	KProcess* prConnect;
	KProcess* prDisconnect;
	KProcess* prStatus;

	KAction* acConnect;		// Menu entries' appearance is modified at runtime
	KAction* acDisconnect;
	KAction* acShowIpAddress;

	QString sAppName, sConnecting, sDisconnecting, sConnected, sDisconnected, sConnect, sDisconnect;
	QPixmap pixConnecting, pixConnected, pixDisconnected, // no separate icon for disconnecting
		pixTraffic[TIMER_ANIMATION_COUNT];

	bool bConnected;
	bool bConnecting;
	bool bIpAddressValid;
	QString sIpAddress;

	bool bCountersValid, bAnimateTrayIcon;
	int iRX, iRXprev;
	int iTX, iTXprev;
	int iCurrentTrayIcon;

	QTimer* iconCheckTimer;
	QTimer* iconAnimationTimer;

	bool getTraffic();
	void setIcon();
	void setToolTip();
	void setMenu();

private slots:
	/** Connect to Internet */
	void slotConnect();
	/** Called when start terminates */
	void slotConnected();

	/** Disconnect from Internet */
	void slotDisconnect();
	/** Called when stop terminates */
	void slotDisconnected();

	/** Consume status (=IP address) from script */
	void slotConsumeStatus(KProcess* proc, char* buf, int len);

	/** Display IP address */
	void slotDisplayIpAddress();
	/** Check for traffic */
	void slotCheckTraffic();
	/** Display traffic as panel icon animation */
	void slotDisplayTraffic();

	/** Show About dialog */
	void slotAbout();
};

#endif // _RPPPPOEK_H_
